describe Page do

    let(:hash) { {
                 title: "A title",
                 website: "A website",
                 description: "A description"
                } }

    subject(:page) { described_class.new(hash) }

    describe '.new' do

        it 'accepts a hash as an argument' do
            expect(described_class).to receive(:new).with(an_instance_of(Hash))
            described_class.new(hash)
        end

        it 'assigns the attributes to the newly initialized object' do
            expect(subject.title).to eq(hash[:title])
            expect(subject.website).to eq(hash[:website])
            expect(subject.description).to eq(hash[:description])
        end

        it 'adds the newly initialized object to @@all' do
            expect(described_class.all).to include(subject)
        end

    end

    describe '.all' do

        it 'returns an array' do
            expect(described_class.all).to be_kind_of(Array)
        end

    end

    describe '.reset_all' do

        it 'resets @@all to an empty array' do
            expect(described_class.reset_all).to eq([])
            expect(described_class.all).to eq([])
        end
    
    end

    describe '.find' do
        
        index = 0

        it 'accepts an index as an argument' do
            expect(described_class).to receive(:find).with(an_instance_of(Integer))
            described_class.find(1)
        end

        it 'finds the correct hash in @@all using the given index' do
            expect(described_class.find(index)).to eq(described_class.all[index-1])
        end

    end

end